.. _requirements:

Requirements
============

Axes requires a supported Django version and runs on Python versions 3.6 and above.

Refer to the project source code repository in
`GitHub <https://github.com/jazzband/django-axes/>`_ and see the
`Travis CI configuration <https://github.com/jazzband/django-axes/blob/master/.travis.yml>`_ and
`Python package definition <https://github.com/jazzband/django-axes/blob/master/setup.py>`_
to check if your Django and Python version are supported.

The `Travis CI builds <https://travis-ci.org/jazzband/django-axes>`_
test Axes compatibility with the Django master branch for future compatibility as well.
